@@ -93,12 +93,43 @@ def cmpdir(candidate:Path, expected:Path):
   
   return not any(len(l) for l in res), res
 
+def toBytes(s:object|bytes):
+  if isinstance(s, bytes) :
+    return s
+  return str(s).encode('utf8')
+
+def findAndReplaceAllInDir(directory:Path, searched:bytes, replacement:bytes):
+  for dname, dirs, files in os.walk(directory):
+    for fname in files:
+      fpath = os.path.join(dname, fname)
+      with open(fpath, "rb") as f:
+        s = f.read()
+      s = s.replace(searched, replacement)
+      with open(fpath, "wb") as f:
+        f.write(s)
+
+class _ExpectDirCounter(object):
+  """
+  Descriptor to use a common counter on ExpectDir instances using the same path
+  """
+  def __init__(self):
+    self.counters = {}
+
+  def __get__(self, obj:'ExpectDir', objtype=None):
+    if obj is None :
+      return self.counters
+    return self.counters.setdefault(str(obj.tmp_path.absolute()), -1)
+  
+  def __set__(self, obj:'ExpectDir', objvalue):
+    self.counters[str(obj.tmp_path.absolute())] = objvalue
+
 class ExpectDir(object):
   """
   Class to handle the teardown, and the assertions
   """
   EMPTY = '__empty__'
-  def __init__(self, tmp_path:Path, request):
+  current = _ExpectDirCounter()
+  def __init__(self, tmp_path:Path, request, default_current_dir_replace_string=None):
     self.tmp_path = tmp_path
     currentFile = Path(request.module.__file__)
     self.cwd = currentFile.parent
@@ -107,10 +138,13 @@ class ExpectDir(object):
       self.fallback = self.fallback / request.cls.__name__
     if request.function :
       self.fallback = self.fallback / request.function.__name__
-    self.current = -1
+    self.default_current_dir_replace_string = default_current_dir_replace_string
+    self.tmp_dir = None
 
   @contextmanager
-  def __call__(self, datapath=None, initial=None, expected=None):
+  def __call__(self, datapath=None, initial=None, expected=None, current_dir_replace_string=None):
+    if current_dir_replace_string is None :
+      current_dir_replace_string = self.default_current_dir_replace_string
     self.current += 1
     if not expected :
       if not datapath :
@@ -135,28 +169,45 @@ class ExpectDir(object):
         raise FileNotFoundError(f'{self.cwd / initial} (as initial directory for expectdir) is not a directory whereas it has been passed explicitely as kwarg.')
         
     
-    tmpdir = self.tmp_path / f'candidate{self.current}'
-    tmpdir.parent.mkdir(parents=True, exist_ok=True)
-    if initial :
-      shutil.copytree(
-        _win32_longpath(str(self.cwd / initial)), _win32_longpath(str(tmpdir))
-      )
-    else :
-      tmpdir.mkdir()
     try :
-      yield tmpdir
-    except :
-      raise
-    else :
-      res, diffRes = cmpdir(tmpdir, self.cwd / expected)
-      if res :
-        return
-      tio = StringIO()
-      formatDiff(tio, tmpdir, self.cwd / expected, diffRes)
-      raise AssertionError(tio.getvalue())
+      self.tmp_dir = self.tmp_path / f'candidate{self.current}'
+      self.tmp_dir.parent.mkdir(parents=True, exist_ok=True)
+      if initial :
+        shutil.copytree(
+          _win32_longpath(str(self.cwd / initial)), _win32_longpath(str(self.tmp_dir))
+        )
+      else :
+        self.tmp_dir.mkdir()
+      if current_dir_replace_string :
+        # Replace the alias (current_dir_replace_string) by the current dir before doing the test
+        alias = toBytes(current_dir_replace_string)
+        path = toBytes(self.tmp_dir)
+        findAndReplaceAllInDir(self.tmp_dir, alias, path)
+      try :
+        yield self.tmp_dir
+      except :
+        raise
+      else :
+        if current_dir_replace_string :
+          # Replace the current dir by the alias after doing the test, so that the comparison works well with the expected result
+          findAndReplaceAllInDir(self.tmp_dir, path, alias)
+        res, diffRes = cmpdir(self.tmp_dir, self.cwd / expected)
+        if res :
+          return
+        tio = StringIO()
+        formatDiff(tio, self.tmp_dir, self.cwd / expected, diffRes)
+        raise AssertionError(tio.getvalue())
+    finally :
+      self.tmp_dir = None
 
 
 @pytest.fixture
 def expectdir(tmp_path, request):
   return ExpectDir(tmp_path, request)
 
+@pytest.fixture
+def expectdirReplace(tmp_path, request):
+  """
+  Equivalent to expectedir() except it provides a default value to current_dir_replace_string
+  """
+  return ExpectDir(tmp_path, request, default_current_dir_replace_string='{{current_directory}}')
